Method: Azure::Batch::Mgmt::V2019_04_01::Models::LinuxUserConfiguration#ssh_private_key

Defined in:
lib/2019-04-01/generated/azure_mgmt_batch/models/linux_user_configuration.rb

#ssh_private_keyString

key must not be password protected. The private key is used to automatically configure asymmetric-key based authentication for SSH between nodes in a Linux pool when the pool’s enableInterNodeCommunication property is true (it is ignored if enableInterNodeCommunication is false). It does this by placing the key pair into the user’s .ssh directory. If not specified, password-less SSH is not configured between nodes (no modification of the user’s .ssh directory is done).

Returns:

  • (String)

    The SSH private key for the user account. The private



35
36
37
# File 'lib/2019-04-01/generated/azure_mgmt_batch/models/linux_user_configuration.rb', line 35

def ssh_private_key
  @ssh_private_key
end