Method: Azure::Batch::Mgmt::V2019_04_01::Models::LinuxUserConfiguration#uid

Defined in:
lib/2019-04-01/generated/azure_mgmt_batch/models/linux_user_configuration.rb

#uidInteger

properties must be specified together or not at all. If not specified the underlying operating system picks the uid.

Returns:

  • (Integer)

    The user ID of the user account. The uid and gid



19
20
21
# File 'lib/2019-04-01/generated/azure_mgmt_batch/models/linux_user_configuration.rb', line 19

def uid
  @uid
end