Class: Azure::Batch::Mgmt::V2019_08_01::Models::AzureBlobFileSystemConfiguration

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb

Overview

Information used to connect to an Azure Storage Container using Blobfuse.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#account_keyString

mutually exclusive with sasKey and one must be specified.

Returns:

  • (String)

    The Azure Storage Account key. This property is



24
25
26
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 24

def 
  @account_key
end

#account_nameString

Returns The Azure Storage Account name.

Returns:

  • (String)

    The Azure Storage Account name.



17
18
19
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 17

def 
  @account_name
end

#blobfuse_optionsString

command. These are ‘net use’ options in Windows and ‘mount’ options in Linux.

Returns:

  • (String)

    Additional command line options to pass to the mount



33
34
35
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 33

def blobfuse_options
  @blobfuse_options
end

#container_nameString

Returns The Azure Blob Storage Container name.

Returns:

  • (String)

    The Azure Blob Storage Container name.



20
21
22
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 20

def container_name
  @container_name
end

#relative_mount_pathString

system will be mounted. All file systems are mounted relative to the Batch mounts directory, accessible via the AZ_BATCH_NODE_MOUNTS_DIR environment variable.

Returns:

  • (String)

    The relative path on the compute node where the file



39
40
41
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 39

def relative_mount_path
  @relative_mount_path
end

#sas_keyString

exclusive with accountKey and one must be specified.

Returns:

  • (String)

    The Azure Storage SAS token. This property is mutually



28
29
30
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 28

def sas_key
  @sas_key
end

Class Method Details

.mapperObject

Mapper for AzureBlobFileSystemConfiguration class as Ruby Hash. This will be used for serialization/deserialization.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 46

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'AzureBlobFileSystemConfiguration',
    type: {
      name: 'Composite',
      class_name: 'AzureBlobFileSystemConfiguration',
      model_properties: {
        account_name: {
          client_side_validation: true,
          required: true,
          serialized_name: 'accountName',
          type: {
            name: 'String'
          }
        },
        container_name: {
          client_side_validation: true,
          required: true,
          serialized_name: 'containerName',
          type: {
            name: 'String'
          }
        },
        account_key: {
          client_side_validation: true,
          required: false,
          serialized_name: 'accountKey',
          type: {
            name: 'String'
          }
        },
        sas_key: {
          client_side_validation: true,
          required: false,
          serialized_name: 'sasKey',
          type: {
            name: 'String'
          }
        },
        blobfuse_options: {
          client_side_validation: true,
          required: false,
          serialized_name: 'blobfuseOptions',
          type: {
            name: 'String'
          }
        },
        relative_mount_path: {
          client_side_validation: true,
          required: true,
          serialized_name: 'relativeMountPath',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end