Class: Azure::Batch::Mgmt::V2019_08_01::Models::AzureBlobFileSystemConfiguration
- Inherits:
-
Object
- Object
- Azure::Batch::Mgmt::V2019_08_01::Models::AzureBlobFileSystemConfiguration
- Includes:
- MsRestAzure
- Defined in:
- lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb
Overview
Information used to connect to an Azure Storage Container using Blobfuse.
Instance Attribute Summary collapse
-
#account_key ⇒ String
mutually exclusive with sasKey and one must be specified.
-
#account_name ⇒ String
The Azure Storage Account name.
-
#blobfuse_options ⇒ String
command.
-
#container_name ⇒ String
The Azure Blob Storage Container name.
-
#relative_mount_path ⇒ String
system will be mounted.
-
#sas_key ⇒ String
exclusive with accountKey and one must be specified.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for AzureBlobFileSystemConfiguration class as Ruby Hash.
Instance Attribute Details
#account_key ⇒ String
mutually exclusive with sasKey and one must be specified.
24 25 26 |
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 24 def account_key @account_key end |
#account_name ⇒ String
Returns The Azure Storage Account name.
17 18 19 |
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 17 def account_name @account_name end |
#blobfuse_options ⇒ String
command. These are ‘net use’ options in Windows and ‘mount’ options in Linux.
33 34 35 |
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 33 def end |
#container_name ⇒ String
Returns The Azure Blob Storage Container name.
20 21 22 |
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 20 def container_name @container_name end |
#relative_mount_path ⇒ String
system will be mounted. All file systems are mounted relative to the Batch mounts directory, accessible via the AZ_BATCH_NODE_MOUNTS_DIR environment variable.
39 40 41 |
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 39 def relative_mount_path @relative_mount_path end |
#sas_key ⇒ String
exclusive with accountKey and one must be specified.
28 29 30 |
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 28 def sas_key @sas_key end |
Class Method Details
.mapper ⇒ Object
Mapper for AzureBlobFileSystemConfiguration class as Ruby Hash. This will be used for serialization/deserialization.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/2019-08-01/generated/azure_mgmt_batch/models/azure_blob_file_system_configuration.rb', line 46 def self.mapper() { client_side_validation: true, required: false, serialized_name: 'AzureBlobFileSystemConfiguration', type: { name: 'Composite', class_name: 'AzureBlobFileSystemConfiguration', model_properties: { account_name: { client_side_validation: true, required: true, serialized_name: 'accountName', type: { name: 'String' } }, container_name: { client_side_validation: true, required: true, serialized_name: 'containerName', type: { name: 'String' } }, account_key: { client_side_validation: true, required: false, serialized_name: 'accountKey', type: { name: 'String' } }, sas_key: { client_side_validation: true, required: false, serialized_name: 'sasKey', type: { name: 'String' } }, blobfuse_options: { client_side_validation: true, required: false, serialized_name: 'blobfuseOptions', type: { name: 'String' } }, relative_mount_path: { client_side_validation: true, required: true, serialized_name: 'relativeMountPath', type: { name: 'String' } } } } } end |